Learn R Programming

expowo (version 3.0)

POWOcodes: Complete list of vascular plant families and associated URI addresses

Description

Complete list of the vascular plants (APG IV-based families of flowering plants, gymnosperms, ferns and lycophytes) and associated URI addresses as retrieved with the function get_pow of the package taxize.

Usage

data(POWOcodes)

Arguments

Format

data.frame